summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMahesh KKV <maheshkkv@google.com>2023-02-05 20:29:38 -0800
committerMahesh KKV <maheshkkv@google.com>2023-02-05 20:37:01 -0800
commitcd75a54c4ab96de930e78bab89bb2d7833aabc80 (patch)
tree1ee5c8f19874d243d9e24219e16fb2b138868b3e
parent55f43fb91ee8e0395a48105d0219c2bba1bf037a (diff)
downloadlibhardware_legacy-cd75a54c4ab96de930e78bab89bb2d7833aabc80.tar.gz
Rename max_mlo_link_count to max_mlo_str_link_count
The maximum number of Simultaneous Transmit Receive (STR) links used in Multi-Link Operation can be different from the maximum radios supported by the chip.Explicitly mention the max links as max STR links. Update the description and usage of the capability field. Bug: 267963579 Test: build and wifi connection Change-Id: Ic12055a4a340aeff15382e198a76328431f9def6
-rw-r--r--include/hardware_legacy/wifi_hal.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/hardware_legacy/wifi_hal.h b/include/hardware_legacy/wifi_hal.h
index efe5ed8..494d653 100644
--- a/include/hardware_legacy/wifi_hal.h
+++ b/include/hardware_legacy/wifi_hal.h
@@ -287,13 +287,13 @@ typedef struct {
typedef struct {
/**
* Maximum number of links used in Multi-Link Operation. The maximum
* number of links used for MLO can be different from the number of
* radios supported by the chip.
*
* This is a static configuration of the chip.
*/
- u32 max_mlo_link_count;
+ u32 max_mlo_str_link_count;
/**
* Maximum number of concurrent TDLS sessions supported by the chip.
*
@@ -287,13 +287,13 @@ typedef struct {
typedef struct {
/**
- * Maximum number of links used in Multi-Link Operation. The maximum
- * number of links used for MLO can be different from the number of
- * radios supported by the chip.
+ * Maximum number of Simultaneous Transmit and Receive (STR) links used
+ * in Multi-Link Operation. The maximum number of STR links used can be
+ * different from the maximum number of radios supported by the chip.
*
* This is a static configuration of the chip.